aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--models/issues/tracked_time.go4
-rw-r--r--models/issues/tracked_time_test.go10
-rw-r--r--routers/web/repo/issue.go4
3 files changed, 9 insertions, 9 deletions
diff --git a/models/issues/tracked_time_test.go b/models/issues/tracked_time_test.go
index caced78c9e..24081f1bfa 100644
--- a/models/issues/tracked_time_test.go
+++ b/models/issues/tracked_time_test.go
@@ -79,10 +79,10 @@ func TestGetTrackedTimes(t *testing.T) {
assert.Len(t, times, 0)
}
-func TestTotalTimes(t *testing.T) {
+func TestTotalTimesForEachUser(t *testing.T) {
assert.NoError(t, unittest.PrepareTestDatabase())
- total, err := issues_model.TotalTimes(&issues_model.FindTrackedTimesOptions{IssueID: 1})
+ total, err := issues_model.TotalTimesForEachUser(&issues_model.FindTrackedTimesOptions{IssueID: 1})
assert.NoError(t, err)
assert.Len(t, total, 1)
for user, time := range total {
@@ -90,7 +90,7 @@ func TestTotalTimes(t *testing.T) {
assert.EqualValues(t, 400, time)
}
- total, err = issues_model.TotalTimes(&issues_model.FindTrackedTimesOptions{IssueID: 2})
+ total, err = issues_model.TotalTimesForEachUser(&issues_model.FindTrackedTimesOptions{IssueID: 2})
assert.NoError(t, err)
assert.Len(t, total, 2)
for user, time := range total {
@@ -103,7 +103,7 @@ func TestTotalTimes(t *testing.T) {
}
}
- total, err = issues_model.TotalTimes(&issues_model.FindTrackedTimesOptions{IssueID: 5})
+ total, err = issues_model.TotalTimesForEachUser(&issues_model.FindTrackedTimesOptions{IssueID: 5})
assert.NoError(t, err)
assert.Len(t, total, 1)
for user, time := range total {
@@ -111,7 +111,7 @@ func TestTotalTimes(t *testing.T) {
assert.EqualValues(t, 1, time)
}
- total, err = issues_model.TotalTimes(&issues_model.FindTrackedTimesOptions{IssueID: 4})
+ total, err = issues_model.TotalTimesForEachUser(&issues_model.FindTrackedTimesOptions{IssueID: 4})
assert.NoError(t, err)
assert.Len(t, total, 2)
}
diff --git a/routers/web/repo/issue.go b/routers/web/repo/issue.go
index b33c9f9727..090d23301b 100644
--- a/routers/web/repo/issue.go
+++ b/routers/web/repo/issue.go
@@ -1549,8 +1549,8 @@ func ViewIssue(ctx *context.Context) {
} else {
ctx.Data["CanUseTimetracker"] = false
}
- if ctx.Data["WorkingUsers"], err = issues_model.TotalTimes(&issues_model.FindTrackedTimesOptions{IssueID: issue.ID}); err != nil {
- ctx.ServerError("TotalTimes", err)
+ if ctx.Data["WorkingUsers"], err = issues_model.TotalTimesForEachUser(&issues_model.FindTrackedTimesOptions{IssueID: issue.ID}); err != nil {
+ ctx.ServerError("TotalTimesForEachUser", err)
return
}
}
diff --git a/models/issues/tracked_time.go b/models/issues/tracked_time.go
index 58c6b775f0..c51df627ac 100644
--- a/models/issues/tracked_time.go
+++ b/models/issues/tracked_time.go
@@ -198,8 +198,8 @@ func addTime(ctx context.Context, user *user_model.User, issue *Issue, amount in
return tt, db.Insert(ctx, tt)
}
-// TotalTimes returns the spent time in seconds for each user by an issue
-func TotalTimes(options *FindTrackedTimesOptions) (map[*user_model.User]int64, error) {
+// TotalTimesForEachUser returns the spent time in seconds for each user by an issue
+func TotalTimesForEachUser(options *FindTrackedTimesOptions) (map[*user_model.User]int64, error) {
trackedTimes, err := GetTrackedTimes(db.DefaultContext, options)
if err != nil {
return nil, err